@@ -14,7 +14,7 @@ import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
 
-class SearchWebDbJob(JobBase):
+class WebDbSearchJob(JobBase):
     """
     Ask user to select a specific search result from an internet database
 
@@ -31,6 +31,12 @@ class SearchWebDbJob(JobBase):
             available. Registered callbacks get `True` for "search started" or
             `False` for "search ended" as a positional argument.
 
+        ``info_updating``
+            Emitted when an attempt to fetch additional information is made.
+            Registered callbacks get the name of an attribute of a
+            :class:`~.utils.webdbs.common.SearchResult` object that returns a
+            coroutine function as a positional argument.
+
         ``info_updated``
             Emitted when additional information is available. Registered
             callbacks are called for each piece of information and get ``key``
@@ -69,11 +75,12 @@ class SearchWebDbJob(JobBase):
         assert isinstance(db, webdbs.WebDbApiBase), f'Not a WebDbApiBase: {db!r}'
         self._db = db
         self._content_path = content_path
-        self._query = webdbs.Query.from_path(content_path)
+        self._query = self._db.sanitize_query(webdbs.Query.from_path(content_path))
         self._is_searching = False
 
         self.signal.add('search_results')
         self.signal.add('searching_status')
+        self.signal.add('info_updating')
         self.signal.add('info_updated')
 
         self._searcher = _Searcher(
@@ -91,8 +98,8 @@ class SearchWebDbJob(JobBase):
                 'summary': self._make_update_info_func('summary'),
                 'title_original': self._make_update_info_func('title_original'),
                 'title_english': self._make_update_info_func('title_english'),
-                'keywords': self._make_update_info_func('keywords'),
-                'director': self._make_update_info_func('director'),
+                'genres': self._make_update_info_func('genres'),
+                'directors': self._make_update_info_func('directors'),
                 'cast': self._make_update_info_func('cast'),
                 'countries': self._make_update_info_func('countries'),
             },
@@ -102,13 +109,16 @@ class SearchWebDbJob(JobBase):
         return lambda value: self._update_info(key, value)
 
     def _update_info(self, attr, value):
-        self.signal.emit('info_updated', attr, value)
+        if value is Ellipsis:
+            self.signal.emit('info_updating', attr)
+        else:
+            self.signal.emit('info_updated', attr, value)
 
     def execute(self):
         """Search for initial query"""
         # It is important NOT to do this in initialize() because the window
         # between initialize() and execute() is used to register callbacks.
-        self._searcher.search(self._query)
+        self.search(self._query)
 
     async def wait(self):
         """Wait for any running internal coroutines"""
@@ -128,7 +138,7 @@ class SearchWebDbJob(JobBase):
     def search(self, query):
         """Make a new search request after cancelling any currently ongoing request"""
         if not self.is_finished:
-            self._query = webdbs.Query.from_string(query)
+            self._query = self._db.sanitize_query(webdbs.Query.from_string(query))
             self._searcher.search(self._query)
             self.clear_warnings()
 
@@ -310,7 +320,8 @@ class _InfoUpdater:
         if cached_value is not None:
             callback(cached_value)
         else:
-            callback('Loading...')
+            # Indicate "Loading..." status
+            callback(Ellipsis)
             await asyncio.sleep(self._delay_between_updates)
             try:
                 value = await value_getter()
