@@ -377,7 +377,7 @@ class BbTrackerJobs(TrackerJobsBase):
                 {'label': 'DTS', 'value': 'DTS', 'regex': re.compile(r'^DTS(?!-HD)')},       # DTS, DTS-ES
                 {'label': 'DTS-HD', 'value': 'DTS-HD', 'regex': re.compile(r'^DTS-HD\b')},   # DTS-HD, DTS-HD MA
                 {'label': 'DTS:X', 'value': 'DTS:X', 'regex': re.compile(r'^DTS:X$')},
-                {'label': 'Dolby Atmos', 'value': 'Atmos', 'regex': re.compile(r'Atmos')},
+                {'label': 'Dolby Atmos', 'value': 'Dolby Atmos', 'regex': re.compile(r'Atmos')},
                 {'label': 'FLAC', 'value': 'FLAC', 'regex': re.compile(r'^FLAC$')},
                 {'label': 'MP3', 'value': 'MP3', 'regex': re.compile(r'^MP3$')},
                 # {'label': 'PCM', 'value': 'PCM', 'regex': re.compile(r'^$')},
@@ -638,7 +638,9 @@ class BbTrackerJobs(TrackerJobsBase):
         # Move/TV Rule 3.6.1 - Encodes with a stored resolution less than 700px
         #                      AND a height less than 460px should be labelled
         #                      "SD"
-        if video.width(self.content_path) < 700 and video.height(self.content_path) < 460:
+        width = video.width(self.content_path)
+        height = video.height(self.content_path)
+        if 0 < width < 700 and 0 < height < 460:
             return 'SD'
 
         # Movie Rule 3.6.2 - 576p PAL encodes with a stored resolution of at
