@@ -31,6 +31,10 @@ class BbTracker(TrackerBase):
     label = 'bB'
 
     argument_definitions = {
+        ('--anime', '--an'): {
+            'help': 'Upload as anime (ignored for movies)',
+            'action': 'store_true',
+        },
         ('--poster-file',): {
             'help': 'Path or URL to poster image',
         },
