@@ -108,11 +108,12 @@ class submit(CommandBase):
     def _get_imghost(self):
         imghost_name = self.tracker_options.get('image_host', None)
         if imghost_name:
+            # Apply tracker-specific image host configuration
             imghost_config = self.config['imghosts'][imghost_name].copy()
             imghost_config.update(self.tracker.TrackerJobs.image_host_config.get(imghost_name, {}))
             return utils.imghosts.imghost(
                 name=imghost_name,
-                **imghost_config,
+                config=imghost_config,
             )
 
     def _get_btclient(self):
@@ -122,7 +123,7 @@ class submit(CommandBase):
         if btclient_name:
             return utils.btclients.client(
                 name=btclient_name,
-                **self.config['clients'][btclient_name],
+                config=self.config['clients'][btclient_name],
             )
 
     def _get_torrent_destination(self):
