@@ -83,7 +83,38 @@ async def post(url, headers={}, data={}, files={}, auth=None,
     :param str url: URL to request
     :param dict headers: Custom headers (added to default headers)
     :param dict data: Data to send as application/x-www-form-urlencoded
-    :param dict files: Files to send as multipart/form-data
+    :param dict files: Files to send as multipart/form-data as a dictionary that
+        maps field names to file paths or dictionaries. For dictionaries, these
+        keys are used:
+
+             ``file``
+                 File path or file-like object, e.g. return value of
+                 :func:`open` or :class:`~.io.BytesIO`.
+
+             ``filename`` (optional)
+                 Name of the file that is reported to the server. Defaults to
+                 :func:`~.os.path.basename` of ``file`` if ``file`` is a string,
+                 `None` otherwise.
+
+             ``mimetype`` (optional)
+                 MIME type of the file content. If not provided and `file` is a
+                 string, guess based on extension of ``file``. If `None`, do not
+                 send any MIME type.
+
+        Examples:
+
+        >>> files = {
+        >>>     "image": "path/to/foo.jpg",
+        >>>     "document": {
+        >>>         "file": "path/to/bar",
+        >>>         "filename": "something.txt",
+        >>>         "mimetype": "text/plain",
+        >>>     },
+        >>>     "data": {
+        >>>         "file": io.BytesIO(b'binary data'),
+        >>>         "mimetype": "application/octet-stream",
+        >>>      },
+        >>> })
     :param auth: Basic access authentication; sequence of <username> and
         <password> or `None`
     :param bool cache: Whether to use cached response if available
@@ -261,36 +292,8 @@ def _open_files(files):
     """
     Open files for upload
 
-    :param files: Dictionary that maps field names to file paths or
-        dictionaries. For dictionaries, these keys are used:
-
-             ``file``
-                 File path or file-like object, e.g. return value of
-                 :func:`open` or an instance of a subclass of
-                 :class:`~.io.IOBase`.
-
-             ``filename`` (optional)
-                 Name of the file that is reported to the server in the
-                 request. Defaults to :func:`~.os.path.basename` of ``file`` if
-                 ``file`` is a string, `None` otherwise.
-
-             ``mimetype`` (optional)
-                 MIME type of the file content. Guess based on ``file`` if not
-                 provided. If `None`, do not send any MIME type.
-
-        Example:
-
-        >>> _open_files({
-        >>>     "image": "path/to/foo.jpg",
-        >>>     "document": {"file": "path/to/bar", "mimetype": "text/plain"},
-        >>>     "data": {
-        >>>         "file": io.IOBytes(b'binary data'),
-        >>>         "filename": "binary.data",
-        >>>         "mimetype": "application/octet-stream",
-        >>>      },
-        >>> })
-
-    :return: See https://www.python-httpx.org/advanced/#multipart-file-encoding
+    See :func:`post` and
+    https://www.python-httpx.org/advanced/#multipart-file-encoding.
 
     :raise RequestError: if a file cannot be opened
     """
@@ -373,7 +376,7 @@ def _cache_file(method, url, params={}):
             filename = f'{method.upper()}.{url}?{params_str}'
         else:
             filename = f'{method.upper()}.{url}'
-        return filename.replace('/', '_').replace(' ', '+')
+        return filename.replace(' ', '+')
 
     if params:
         params_str = '&'.join((f'{k}={v}' for k,v in params.items()))
@@ -394,14 +397,14 @@ def _semantic_hash(obj):
 
     https://github.com/schollii/sandals/blob/master/json_sem_hash.py
     """
-    def sorted_dict_str(obj):
+    def as_str(obj):
         if isinstance(obj, collections.abc.Mapping):
-            return {k: sorted_dict_str(obj[k]) for k in sorted(obj.keys())}
+            return {as_str(k): as_str(obj[k]) for k in sorted(obj.keys())}
         elif isinstance(obj, str):
             return str(obj)
         elif isinstance(obj, collections.abc.Sequence):
-            return [sorted_dict_str(val) for val in obj]
+            return [as_str(val) for val in sorted(obj)]
         else:
             return str(obj)
 
-    return hashlib.sha256(bytes(repr(sorted_dict_str(obj)), 'UTF-8')).hexdigest()
+    return hashlib.sha256(bytes(repr(as_str(obj)), 'UTF-8')).hexdigest()
