@@ -11,23 +11,20 @@ from .verify import (assert_not_abbreviated_filename, is_scene_release,
                      release_files, verify_release, verify_release_files,
                      verify_release_name)
 
-import logging  # isort:skip
-_log = logging.getLogger(__name__)
-
 
 def scenedbs():
     """Return list of :class:`.SceneDbApiBase` subclasses"""
     return utils.subclasses(SceneDbApiBase, utils.submodules(__package__))
 
 
-def scenedb(name, **kwargs):
+def scenedb(name, config=None):
     """
     Create :class:`.SceneDbApiBase` instance
 
     :param str name: Name of the scene release database. A subclass of
         :class:`.SceneDbApiBase` with the same :attr:`~.SceneDbApiBase.name` must
         exist in one of this package's submodules.
-    :param kwargs: All keyword arguments are passed to the subclass specified by
+    :param dict config: User configuration passed to the subclass specified by
         `name`
 
     :raise ValueError: if no matching subclass can be found
@@ -36,7 +33,7 @@ def scenedb(name, **kwargs):
     """
     for scenedb in scenedbs():
         if scenedb.name == name:
-            return scenedb(**kwargs)
+            return scenedb(config=config)
     raise ValueError(f'Unsupported scene release database: {name}')
 
 
