@@ -20,8 +20,10 @@ class ImdbApi(WebDbApiBase):
 
     name = 'imdb'
     label = 'IMDb'
-    _url_base = 'https://imdb.com'
 
+    default_config = {}
+
+    _url_base = 'https://imdb.com'
     _soup_cache = {}
 
     async def _get_soup(self, path, params={}):
@@ -310,6 +312,7 @@ class ImdbApi(WebDbApiBase):
         re.compile(r'^USA.*English'),
         re.compile(r'^USA$'),
         re.compile(r'^World-wide.*English'),
+        re.compile(r'^USA.*reissue'),
     )
 
     async def _get_akas(self, id):
@@ -468,7 +471,9 @@ class _ImdbSearchResult(common.SearchResult):
 
         tags = soup.find_all(class_='text-muted')
         if len(tags) >= 3:
-            summary = (tags[2].string or '').strip()
+            strings = tuple(tags[2].strings)
+            if strings and 'Add a Plot' not in strings:
+                summary = (''.join(strings) or '').strip()
 
         # Look for "See full summary" link. Preceding text is summary.
         if not summary:
@@ -477,7 +482,9 @@ class _ImdbSearchResult(common.SearchResult):
                 summary_tag = summary_link.parent
                 if summary_tag:
                     summary = ''.join(summary_tag.strings)
-                    summary = re.sub(r'See full summary.*', '', summary).strip()
+
+        summary = re.sub(r'(?i:see full summary).*', '', summary).strip()
+        summary = re.sub(r'\s*\.\.\.\s*$', '…', summary)
 
         return summary
 
