@@ -2,6 +2,7 @@
 API for tvmaze.com
 """
 
+import collections
 import functools
 import json
 
@@ -21,6 +22,9 @@ class TvmazeApi(WebDbApiBase):
 
     name = 'tvmaze'
     label = 'TVmaze'
+
+    default_config = {}
+
     _url_base = 'http://api.tvmaze.com'
 
     def __init__(self, *args, **kwargs):
@@ -68,7 +72,7 @@ class TvmazeApi(WebDbApiBase):
         response = await http.get(url, cache=True)
         try:
             info = json.loads(response)
-            assert isinstance(info, (dict, list))
+            assert isinstance(info, (collections.abc.Mapping, collections.abc.Sequence))
         except (ValueError, TypeError, AssertionError):
             raise errors.RequestError(f'Unexpected search response: {response}')
         else:
